@@ -16,35 +16,39 @@ extensions = [
     "sphinx.ext.intersphinx",
     "pallets_sphinx_themes",
     "sphinx_issues",
+    "sphinxcontrib.log_cabinet",
 ]
+autoclass_content = "both"
+autodoc_typehints = "description"
 intersphinx_mapping = {"python": ("https://docs.python.org/3/", None)}
 issues_github_path = "pallets/werkzeug"
 
 # HTML -----------------------------------------------------------------
 
 html_theme = "werkzeug"
+html_theme_options = {"index_sidebar_logo": False}
 html_context = {
     "project_links": [
-        ProjectLink("Donate to Pallets", "https://www.palletsprojects.com/donate"),
-        ProjectLink("Werkzeug Website", "https://palletsprojects.com/p/werkzeug/"),
-        ProjectLink("PyPI releases", "https://pypi.org/project/Werkzeug/"),
+        ProjectLink("Donate", "https://palletsprojects.com/donate"),
+        ProjectLink("PyPI Releases", "https://pypi.org/project/Werkzeug/"),
         ProjectLink("Source Code", "https://github.com/pallets/werkzeug/"),
         ProjectLink("Issue Tracker", "https://github.com/pallets/werkzeug/issues/"),
+        ProjectLink("Chat", "https://discord.gg/pallets"),
     ]
 }
 html_sidebars = {
-    "index": ["project.html", "localtoc.html", "searchbox.html"],
-    "**": ["localtoc.html", "relations.html", "searchbox.html"],
+    "index": ["project.html", "localtoc.html", "searchbox.html", "ethicalads.html"],
+    "**": ["localtoc.html", "relations.html", "searchbox.html", "ethicalads.html"],
 }
-singlehtml_sidebars = {"index": ["project.html", "localtoc.html"]}
+singlehtml_sidebars = {"index": ["project.html", "localtoc.html", "ethicalads.html"]}
 html_static_path = ["_static"]
-html_favicon = "_static/favicon.ico"
-html_logo = "_static/werkzeug.png"
-html_title = "Werkzeug Documentation ({})".format(version)
+html_favicon = "_static/shortcut-icon.png"
+html_logo = "_static/werkzeug-vertical.png"
+html_title = f"Werkzeug Documentation ({version})"
 html_show_sourcelink = False
 
 # LaTeX ----------------------------------------------------------------
 
 latex_documents = [
-    (master_doc, "Werkzeug-{}.tex".format(version), html_title, author, "manual")
+    (master_doc, f"Werkzeug-{version}.tex", html_title, author, "manual")
 ]
